References
----------

.. [Traag18] Traag *et al.* (2019),
   *From Louvain to Leiden: guaranteeing well-connected communities*,
   `Sci Rep <https://doi.org/10.1038/s41598-019-41695-z>`__.

.. [Blondel08] Blondel *et al.* (2008),
   *Fast unfolding of communities in large networks*,
   `J. Stat. Mech. <https://doi.org/10.1088/1742-5468/2008/10/P10008>`__.

.. [Levine15] Levine *et al.* (2015),
    *Data-Driven Phenotypic Dissection of AML Reveals Progenitor--like Cells that Correlate with Prognosis*,
    `Cell <https://doi.org/10.1016/j.cell.2015.05.047>`__.

.. [Zhang21] Zhang *et al.* (2021),
    *A single-cell atlas of chromatin accessibility in the human genome*,
    `Cell <https://doi.org/10.1016/j.cell.2021.10.024>`__.

.. [Weirauch14] Weirauch *et al.* (2014),
    *Determination and inference of eukaryotic transcription factor sequence specificity*,
    `Cell <https://doi.org/10.1016/j.cell.2014.08.009>`__.

.. [Meuleman20] Meuleman *et al.* (2020),
    *Index and biological spectrum of human DNase I hypersensitive sites*,
    `Nature <https://doi.org/10.1038/s41586-020-2559-3>`__.

.. [Miao24] Miao *et al.* (2024),
    *Uniform quantification of single-nucleusATAC-seq data with Paired-InsertionCounting (PIC) and a model-based insertionrate estimator*,
    `Nature Methods <https://doi.org/10.1038/s41592-023-02103-7>`__.